#
# spec file for package expect
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           expect
Version:        5.45.4
Release:        6.9
Summary:        A Tool for Automating Interactive Programs
License:        SUSE-Public-Domain
Group:          Development/Languages/Tcl
URL:            https://core.tcl-lang.org/expect/
Source:         https://downloads.sourceforge.net/expect/expect%version.tar.gz
Source1:        expect-rpmlintrc
Patch1:         expect.patch
Patch2:         expect-fixes.patch
Patch3:         expect-log.patch
Patch4:         config-guess-sub-update.patch
Patch5:         expect-errorfd.patch
Patch6:         expect-5.45-format-security.patch
BuildRequires:  autoconf
BuildRequires:  tcl-devel

%description
Expect is a tool primarily for automating interactive applications,
such as telnet, ftp, passwd, fsck, rlogin, tip, and more.  Expect
really makes this stuff trivial.  Expect is also useful for testing
these applications.  It is described in many books, articles, papers,
and FAQs.  There is an entire book on it available from O'Reilly.

%package devel
Summary:        Header Files and C API Documentation for expect
Group:          Development/Libraries/Tcl

%description devel
This package contains header files and documentation needed for linking
to expect from programs written in compiled languages like C, C++, etc.

This package is not needed for developing scripts that run under the
/usr/bin/expect interpreter, or any other Tcl interpreter with the
expect package loaded.

%prep
%setup -q -n %name%version
%autopatch -p0

%build
export CFLAGS="%{optflags} -fPIC -pie"
autoreconf
%configure \
	--with-tcl=%_libdir \
	--with-tk=no_tk \
	--with-tclinclude=%_includedir \
	--enable-shared
make SHLIB_LD="gcc -shared" %{?_smp_mflags} all pkglibdir=%_libdir/tcl/%name%version

%check
make %{?_smp_mflags} test

%install
# set the right path to the expect binary...
sed -i \
    -e '1s,^#![^ ]*expectk,#!%_bindir/wish\npackage require Expect,' \
    -e '1s,^#![^ ]*expect,#!%_bindir/expect,' \
    example/*
%make_install pkglibdir=%_libdir/tcl/%name%version
# Remove some executables and manpages we don't want to ship
rm %buildroot%_bindir/*passwd
rm %buildroot%_bindir/weather
rm %buildroot%_mandir/*/*passwd*
# Simplify linking for apps that use Expect without Tcl
ln -s libexpect%version.so %buildroot%_libdir/libexpect.so

%files
%_bindir/*
%_libdir/tcl/*
%_libdir/lib*.so
%_mandir/man1/*
%doc ChangeLog HISTORY INSTALL FAQ NEWS README

%files devel
%_libdir/libexpect.so
%_includedir/*
%_mandir/man3/*

%changelog
* Tue Apr 19 2022 Dirk Müller <dmueller@suse.com>
- add expect-5.45-format-security.patch
* Tue Dec 21 2021 Ludwig Nussel <lnussel@suse.de>
- Fix home page URL https://core.tcl-lang.org/expect/
* Mon May 10 2021 Reinhard Max <max@suse.com>
- bsc#1183904, expect-errorfd.patch:
  errorfd file descriptors should be closed when forking
* Tue May  4 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- fix previous change regarding PIE linking. Passing SHLIB_CFLAGS="-shared"
  causes /usr/bin/expect to become a shared library that SEGFAULTs upon
  execution. Instead use SHLIB_LD to pass -shared only to shared library
  linking.
* Wed Apr 21 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- pass explicit -pie flag to CFLAGS and hack `make` invocation so that
  /usr/bin/expect actually becomes a PIE binary. This is especially awkard
  since the expect build system implicitly passes -fPIC which breaks our
  gcc-PIE package, but does not pass -pie while linking the executable.
  Shared libraries are also not linked with -shared so we need to explicitly
  pass this, too, to avoid build breakage (bsc#1184122).
* Thu Oct 15 2020 Reinhard Max <max@suse.com>
- Add an unversioned symlink to make linking easier for
  applications that use libexpect without Tcl (boo#1172681).
* Thu Oct 25 2018 Reinhard Max <max@suse.com>
- New version 5.45.4:
  * Fix two bugs in EOF handling.
* Wed Nov  8 2017 aavindraa@gmail.com
- New version 5.45.3:
  * expect.c: On finding a full buffer during matching the sliding
    window mechanism slides too far, truncating the whole buffer and
    preventing matches across the boundary. Fix is shortening the
    slide distance (slide only one 1/3).
  * expect.c: Replaced a cc==0 check with proper Tcl_Eof() check.
- Includes changes from 5.45.2:
  * configure: Extended Tcl header detection for OS X Mountain Lion.
  * expect.c: Replaced memcpy with memmove to properly handle
    overlapping memory.
- Includes changes from 5.45.1:
  * exp_chan.c: Fix a problem when talking a tty where the writer
    dies. Some operating systems report the condition as EIO with
    nothing read, while this actually an EOF. Previously, returned
    data was incomplete due to the error causing data in buffers to
    be dropped.
  * exp_chan.c: Fix a problem with the iteration over the expect
    channel list where the loop code may modify the list, breaking
    the iterator.
  * Fixes for exp_chan.c and exp_command.h
  * expect.c: Convert #bytes information to #chars to prevent later
    code to fail when copying strings around and miscalculating how
    much to copy, for strings containing non-ASCII utf chars.
  * exp_inter.c: Hack access to TCL_REG_BOSONLY when not present,
    became private with Tcl 8.5 and higher.
  * expect.h: Remove the local fiddling with the memory allocation
    and panic macros.
  * example/unbuffer: Prevent unbuffer from swallowing exit code of
    the command it ran (regular mode only, not -p)
  * Various deduplications and cleanups
- cleanup with spec-cleaner
- use %%make_install macro
* Fri Jul 17 2015 max@suse.com
- Don't ship the 'weather' example anymore (fate#318342).
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Feb  6 2013 schwab@suse.de
- Update config.guess/sub for aarch64
* Sat Apr 14 2012 schwab@linux-m68k.org
- Remove execute permission from logfiles
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Fri Oct  7 2011 max@suse.com
- New version 5.45:
  * Examples now use the expect package instead of /usr/bin/expect.
  * Countless other bug fixes. For details, see
    /usr/share/doc/packages/expect/ChangeLog
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon May 25 2009 max@suse.de
- Fix buffer overflow in the "stty" command
  (bnc#506873, bnc#501291).
* Tue Oct 14 2008 max@suse.de
- Update to version 5.44.1.11 from CVS. The changes mainly consist
  of our former expect-fixes.patch and expect-warnings.patch, plus
  some more bug fixes, e.g. for the [expect -exact] crash reported
  at bnc#427270 .
* Tue Oct 14 2008 meissner@suse.de
- fixed fortify implicits.
* Tue May  6 2008 aj@suse.de
- Add missing return values.
* Thu Apr  3 2008 max@suse.de
- Fixed swapped arguments in prototype of exp_cmd_init()
- Adjusted installation to the new Tcl file system layout
* Thu Mar 20 2008 max@suse.de
- Update to version 5.44.1.5 from CVS:
  * Improved internal buffer management
  * Ported script-level commands to the newer Tcl object API
  * Optimized regular expression matching
- Split off a -devel subpackage
- Don't package the example subdir anymore.
- Fix all critical and part of the non-critical warnings that
  show up with gcc 4.3. To be continued...
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 13 2005 max@suse.de
- Fixed a typo in tcl.m4 that broke configure with bash 3.1.
- Updated expect-CVS.patch.bz2 .
* Thu Sep 22 2005 ro@suse.de
- fix some missing declarations
* Tue Jun 14 2005 max@suse.de
- New version: 5.43 plus patch to current CVS head.
- Disabled building of the static library.
- Moved script library to /usr/share/tcl .
* Tue Jul 13 2004 max@suse.de
- New version: 5.41.
* Mon Mar  1 2004 max@suse.de
- Re-enabled the test suite and added expect-send_tty.patch to
  prevent it from crashing.
* Fri Feb 27 2004 max@suse.de
- New version: 5.40
- Fixed warnings that broke build (expect-warnings.patch).
- Temporarily disabled "make test" to prevent crashes in autobuild
  on some architectures (ppc, s390).
* Fri Oct 31 2003 max@suse.de
- New version: 5.39
- Buliding as non-root user
* Tue May 27 2003 ro@suse.de
- package include files and static lib as well
* Tue Jan 28 2003 max@suse.de
- Fixed path to /usr/bin/write in kibitz.
* Fri Jan 10 2003 max@suse.de
- Fixed a segfault case during application shutdown, and sent
  the patch to the author.
* Tue Nov 26 2002 max@suse.de
- New version: 5.38
- Don't build the expectk binary anymore to remove the buildtime
  dependency on Tk and X. Scripts that needed to run in expectk
  before can be fixed by running them in expect and adding a line
  that says "package require Tk" before the first tk command
  is executed.
* Mon Aug 19 2002 aj@suse.de
- Read all input from invoked program.
* Wed Apr  3 2002 max@suse.de
- Replaced autoreconf by autoconf because it breaks on
  autoconf-2.53 and was overkill anyways.
* Wed Feb 20 2002 max@suse.de
- Fixed for lib64-s390x.
* Thu Jan 24 2002 max@suse.de
- Removed the mkpasswd manpage due to a file name conflict and
  because the respective program is also not included.
* Fri Jan 18 2002 max@suse.de
- added tk to neededforbuild to prevent linking to static libtk
  which is included in tcl-devel
* Thu Jan 17 2002 ro@suse.de
- fixed neededforbuild
* Thu Jan 17 2002 max@suse.de
- New version 5.34.
- Separated this package from the tcl source RPM, because it
  doesn not any longer need the Tcl and Tk sources at hand.
